@@ -172,7 +172,7 @@ class Account(BaseObject):
     id = schema.Column(types.Integer(), primary_key=True, autoincrement=True)
     loginname = schema.Column(types.String(255), nullable=False,
             index=True, unique=True)
-    password = schema.Column(types.Unicode(64), nullable=False)
+    password = schema.Column(types.Unicode(64))
     tc_approved = schema.Column(types.Integer())
 
     @property
@@ -473,6 +473,7 @@ class ActionPlan(BaseObject):
     budget = schema.Column(types.Integer())
     planning_start = schema.Column(types.Date())
     planning_end = schema.Column(types.Date())
+    reference = schema.Column(types.Text())
 
     risk = orm.relation(Risk,
             backref=orm.backref("action_plans",
